@@ -1,6 +1,7 @@
+from __future__ import annotations
+
 import argparse
 import logging.handlers
-import time
 import uuid
 from pathlib import Path
 from typing import Optional
@@ -20,9 +21,12 @@ class UploadInstruction(AbstractCommandLineInterface):
     """
 
     def upload_html_to_instruction(self, project_id: str, html_path: Path):
-        pq_html = pyquery.PyQuery(filename=str(html_path))
+        with html_path.open(encoding="utf-8") as f:
+            file_content = f.read()
+        pq_html = pyquery.PyQuery(file_content)
         pq_img = pq_html("img")
 
+        img_path_dict: dict[str, str] = {}
         # 画像をすべてアップロードして、img要素のsrc属性値を annofab urlに変更する
         for img_elm in pq_img:
             src_value: str = img_elm.attrib.get("src")
@@ -37,16 +41,27 @@ class UploadInstruction(AbstractCommandLineInterface):
             else:
                 img_path = html_path.parent / src_value
 
+            if str(img_path) in img_path_dict:
+                image_id = img_path_dict[str(img_path)]
+                img_url = f"https://annofab.com/projects/{project_id}/instruction-images/{image_id}"
+                img_elm.attrib["src"] = img_url
+                continue
+
             if img_path.exists():
                 image_id = str(uuid.uuid4())
-                img_url = self.service.wrapper.upload_instruction_image(project_id, image_id, str(img_path))
 
-                logger.debug(f"image uploaded. file={img_path}, instruction_image_url={img_url}")
-                img_elm.attrib["src"] = img_url
-                time.sleep(1)
+                try:
+                    img_url = self.service.wrapper.upload_instruction_image(project_id, image_id, str(img_path))
+                    logger.debug(f"image uploaded. file={img_path}, instruction_image_url={img_url}")
+                    img_elm.attrib["src"] = img_url
+                    img_path_dict[str(img_path)] = image_id
+                except Exception as e:  # pylint: disable=broad-except
+                    logger.warning(f"作業ガイドの画像登録に失敗しました。image_id={image_id}, img_path={img_path}, {e}")
+                    continue
 
             else:
                 logger.warning(f"image does not exist. path={img_path}")
+                continue
 
         # body要素があればその中身、なければhtmlファイルの中身をアップロードする
         if len(pq_html("body")) > 0:
