@@ -10,10 +10,10 @@ from annofabcli.statistics.table import _add_ratio_column_for_productivity_per_u
 
 logger = logging.getLogger(__name__)
 
-FILENAME_WHOLE_PEFORMANCE = "全体の生産性と品質.csv"
-FILENAME_PEFORMANCE_PER_USER = "メンバごとの生産性と品質.csv"
+FILENAME_WHOLE_PERFORMANCE = "全体の生産性と品質.csv"
+FILENAME_PERFORMANCE_PER_USER = "メンバごとの生産性と品質.csv"
 
-FILENAME_PEFORMANCE_PER_DATE = "日毎の生産量と生産性.csv"
+FILENAME_PERFORMANCE_PER_DATE = "日毎の生産量と生産性.csv"
 FILENAME_TASK_LIST = "タスクlist.csv"
 
 
@@ -27,7 +27,7 @@ def _get_phase_list(df_member_performance: pandas.DataFrame) -> List[str]:
     return phase_list
 
 
-def _read_whole_peformance_csv(csv_path: Path) -> pandas.Series:
+def _read_whole_performance_csv(csv_path: Path) -> pandas.Series:
     """
     '全体の生産量と生産性.csv' を読み込む。
     プロジェクト名はディレクトリ名とする。
@@ -44,7 +44,7 @@ def _read_whole_peformance_csv(csv_path: Path) -> pandas.Series:
     return series
 
 
-def write_summarise_whole_peformance_csv(csv_path_list: List[Path], output_path: Path) -> None:
+def write_summarise_whole_performance_csv(csv_path_list: List[Path], output_path: Path) -> None:
     """
     `プロジェクトごとの生産性と品質.csv` を出力する。
 
@@ -53,7 +53,7 @@ def write_summarise_whole_peformance_csv(csv_path_list: List[Path], output_path:
         output_path: 出力先
 
     """
-    series_list = [_read_whole_peformance_csv(csv_path) for csv_path in csv_path_list]
+    series_list = [_read_whole_performance_csv(csv_path) for csv_path in csv_path_list]
     df = pandas.DataFrame(series_list)
 
     phase_list = _get_phase_list(df)
@@ -393,7 +393,7 @@ class Csv:
         for phase in phase_list:
             sum_series[("working_user_count", phase)] = (df[("task_count", phase)] > 0).sum()
 
-        self._write_csv_for_series(FILENAME_WHOLE_PEFORMANCE, sum_series)
+        self._write_csv_for_series(FILENAME_WHOLE_PERFORMANCE, sum_series)
 
     def write_count_summary(self, df: pandas.DataFrame) -> None:
         """
@@ -617,7 +617,7 @@ class Csv:
         required_columns = self.create_required_columns(df, prior_columns, dropped_columns)
         target_df = df[required_columns]
         if output_path is None:
-            self._write_csv(FILENAME_PEFORMANCE_PER_USER, target_df)
+            self._write_csv(FILENAME_PERFORMANCE_PER_USER, target_df)
         else:
             print_csv(target_df, output=str(output_path), to_csv_kwargs=self.CSV_FORMAT)
 
@@ -664,6 +664,6 @@ class Csv:
         required_columns = self.create_required_columns(df, prior_columns, dropped_columns)
         target_df = df[required_columns]
         if output_path is None:
-            self._write_csv(FILENAME_PEFORMANCE_PER_DATE, target_df)
+            self._write_csv(FILENAME_PERFORMANCE_PER_DATE, target_df)
         else:
             print_csv(target_df, output=str(output_path), to_csv_kwargs=self.CSV_FORMAT)
