@@ -16,10 +16,14 @@ from dataclasses_json import DataClassJsonMixin
 
 import annofabcli
 from annofabcli import AnnofabApiFacade
-from annofabcli.common.cli import AbstractCommandLineInterface, build_annofabapi_resource_and_login
+from annofabcli.common.cli import (
+    COMMAND_LINE_ERROR_STATUS_CODE,
+    AbstractCommandLineInterface,
+    build_annofabapi_resource_and_login,
+)
 from annofabcli.common.facade import TaskQuery
 from annofabcli.stat_visualization.merge_visualization_dir import merge_visualization_dir
-from annofabcli.statistics.csv import FILENAME_WHOLE_PEFORMANCE, Csv, write_summarise_whole_peformance_csv
+from annofabcli.statistics.csv import FILENAME_WHOLE_PERFORMANCE, Csv, write_summarise_whole_performance_csv
 from annofabcli.statistics.database import Database, Query
 from annofabcli.statistics.linegraph import LineGraph, OutputTarget
 from annofabcli.statistics.scatter import Scatter
@@ -90,7 +94,7 @@ class WriteCsvGraph:
         self.project_id = project_id
         self.table_obj = table_obj
         self.csv_obj = Csv(str(output_dir))
-        # holoviewsのloadに時間がかかって、helpコマンドの出力が遅いため、遅延ロードする
+        # holoviews のloadに時間がかかって、helpコマンドの出力が遅いため、遅延ロードする
         histogram_module = importlib.import_module("annofabcli.statistics.histogram")
         self.histogram_obj = histogram_module.Histogram(str(output_dir / "histogram"))  # type: ignore
         self.linegraph_obj = LineGraph(str(output_dir / "line-graph"))
@@ -631,7 +635,7 @@ class VisualizeStatistics(AbstractCommandLineInterface):
     def main(self):
         args = self.args
         if not self.validate(args):
-            return
+            sys.exit(COMMAND_LINE_ERROR_STATUS_CODE)
 
         dict_task_query = annofabcli.common.cli.get_json_from_args(args.task_query)
         task_query: Optional[TaskQuery] = TaskQuery.from_dict(dict_task_query) if dict_task_query is not None else None
@@ -701,9 +705,9 @@ class VisualizeStatistics(AbstractCommandLineInterface):
                     logger.warning(f"出力した統計情報は1件以下なので、`merge`ディレクトリを出力しません。")
 
             if len(output_project_dir_list) > 0:
-                whole_peformance_csv_list = [e / FILENAME_WHOLE_PEFORMANCE for e in output_project_dir_list]
-                write_summarise_whole_peformance_csv(
-                    csv_path_list=whole_peformance_csv_list, output_path=root_output_dir / "プロジェクトごとの生産性と品質.csv"
+                whole_performance_csv_list = [e / FILENAME_WHOLE_PERFORMANCE for e in output_project_dir_list]
+                write_summarise_whole_performance_csv(
+                    csv_path_list=whole_performance_csv_list, output_path=root_output_dir / "プロジェクトごとの生産性と品質.csv"
                 )
             else:
                 logger.warning(f"出力した統計情報は0件なので、`プロジェクトごとの生産性と品質.csv`を出力しません。")
